# Generated by roxygen2: do not edit by hand

S3method(collect_metrics,tune_race)
S3method(collect_predictions,tune_race)
S3method(print,control_race)
S3method(print,control_sim_anneal)
S3method(show_best,tune_race)
S3method(tune_race_anova,default)
S3method(tune_race_anova,formula)
S3method(tune_race_anova,model_spec)
S3method(tune_race_anova,recipe)
S3method(tune_race_anova,workflow)
S3method(tune_race_win_loss,default)
S3method(tune_race_win_loss,formula)
S3method(tune_race_win_loss,model_spec)
S3method(tune_race_win_loss,recipe)
S3method(tune_race_win_loss,workflow)
S3method(tune_sim_anneal,default)
S3method(tune_sim_anneal,formula)
S3method(tune_sim_anneal,model_spec)
S3method(tune_sim_anneal,recipe)
S3method(tune_sim_anneal,workflow)
export(control_race)
export(control_sim_anneal)
export(plot_race)
export(tune_race_anova)
export(tune_race_win_loss)
export(tune_sim_anneal)
import(tune)
importFrom(dplyr,"%>%")
importFrom(dplyr,distinct)
importFrom(rlang,caller_env)
importFrom(rlang,syms)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,dist)
importFrom(stats,lm)
importFrom(stats,qt)
importFrom(stats,reorder)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(utils,globalVariables)
