# control_race bad arg passing

    Argument 'verbose' should be a single logical value in `control_race()`

---

    Argument 'verbose' should be a single logical value in `control_race()`

---

    Argument 'verbose_elim' should be a single logical value in `control_race()`

---

    Argument 'verbose_elim' should be a single logical value in `control_race()`

---

    Argument 'save_pred' should be a single logical value in `control_race()`

---

    Argument 'save_pred' should be a single logical value in `control_race()`

---

    Argument 'save_workflow' should be a single logical value in `control_race()`

---

    Argument 'save_workflow' should be a single logical value in `control_race()`

---

    Argument 'burn_in' should be a single numeric value in `control_race()`

---

    Argument 'burn_in' should be a single numeric value in `control_race()`

---

    `burn_in` should be at least two.

---

    Argument 'num_ties' should be a single numeric value in `control_race()`

---

    Argument 'num_ties' should be a single numeric value in `control_race()`

---

    Argument 'alpha' should be a single numeric value in `control_race()`

---

    Argument 'alpha' should be a single numeric value in `control_race()`

---

    `alpha` should be on (0, 1).

---

    Argument 'pkgs' should be a character or NULL in `control_race()`

---

    Argument 'extract' should be a function or NULL in `control_race()`

# casting control_race to control_grid

    Code
      parsnip::condense_control(control_race(), control_grid())
    Output
      grid/resamples control object

