# anova filtering and logging

    Code
      finetune:::log_racing(control_race(verbose_elim = TRUE), anova_res,
      ames_grid_search$splits, 10, "rmse")
    Message
      i Fold10: 7 eliminated; 3 candidates remain.

---

    Code
      finetune:::log_racing(control_race(verbose_elim = TRUE), anova_res,
      ames_grid_search$splits, 10, "rmse")
    Message
      i Fold10: 7 eliminated; 3 candidates remain.

---

    Code
      finetune:::log_racing(control_race(verbose_elim = TRUE), anova_res,
      ames_grid_search$splits, 10, "rmse")
    Message
      i Fold10: 7 eliminated; 3 candidates remain.

